@@ -1,4 +1,4 @@
-/* $Id: generateCuts.cpp 736 2011-07-04 02:27:17Z pbelotti $
+/* $Id: generateCuts.cpp 946 2013-04-15 22:20:38Z stefan $
  *
  * Name:    generateCuts.cpp
  * Author:  Pietro Belotti
@@ -91,7 +91,11 @@ void updateBranchInfo (const OsiSolverInterface &si, CouenneProblem *p,
 
 void CouenneCutGenerator::generateCuts (const OsiSolverInterface &si,
 					OsiCuts &cs, 
-					const CglTreeInfo info) const {
+					const CglTreeInfo info)
+#if CGL_VERSION_MAJOR == 0 && CGL_VERSION_MINOR <= 57
+  const
+#endif
+  {
 
   // check if out of time or if an infeasibility cut (iis of type 0)
   // was added as a result of, e.g., pruning on BT. If so, no need to
@@ -111,11 +115,15 @@ void CouenneCutGenerator::generateCuts (const OsiSolverInterface &si,
   if(currCutOff > bestVal) {
     //problem_ -> setCutOff (bestVal - 1e-6); // FIXME: don't add numerical constants
     problem_ -> setCutOff (bestVal);
-    OsiColCut *objCut = new OsiColCut;
+
     int indObj = problem_->Obj(0)->Body()->Index();
-    objCut->setUbs(1, &indObj, &bestVal);
-    cs.insert(objCut);
-    delete objCut;
+
+    if (indObj >= 0) {
+      OsiColCut *objCut = new OsiColCut;
+      objCut->setUbs(1, &indObj, &bestVal);
+      cs.insert(objCut);
+      delete objCut;
+    }
   }
 #endif
 
@@ -235,14 +243,14 @@ void CouenneCutGenerator::generateCuts (const OsiSolverInterface &si,
       CouenneConstraint *con = problem_ -> Con (i);
 
       // (which has an aux as its body)
-      int index = con -> Body () -> Index ();
+      int objindex = con -> Body () -> Index ();
 
-      if ((index >= 0) && 
+      if ((objindex >= 0) && 
 	  ((con -> Body () -> Type () == AUX) ||
 	   (con -> Body () -> Type () == VAR))) {
 
 	// get the auxiliary that is at the lhs
-	exprVar *conaux = problem_ -> Var (index);
+	exprVar *conaux = problem_ -> Var (objindex);
 
 	if (conaux &&
 	    (conaux -> Type () == AUX) &&
@@ -257,8 +265,8 @@ void CouenneCutGenerator::generateCuts (const OsiSolverInterface &si,
 	    ub = (*(con -> Ub ())) ();
 
 	  OsiColCut newBound;
-	  if (lb > -COUENNE_INFINITY) newBound.setLbs (1, &index, &lb);
-	  if (ub <  COUENNE_INFINITY) newBound.setUbs (1, &index, &ub);
+	  if (lb > -COUENNE_INFINITY) newBound.setLbs (1, &objindex, &lb);
+	  if (ub <  COUENNE_INFINITY) newBound.setUbs (1, &objindex, &ub);
 
 	  cs.insert (newBound);
 
@@ -343,9 +351,9 @@ void CouenneCutGenerator::generateCuts (const OsiSolverInterface &si,
     CouenneConstraint *con = problem_ -> Con (i);
 
     // (which has an aux as its body)
-    int index = con -> Body () -> Index ();
+    int objindex = con -> Body () -> Index ();
 
-    if ((index >= 0) && 
+    if ((objindex >= 0) && 
 	((con -> Body () -> Type () == AUX) ||
 	 (con -> Body () -> Type () == VAR))) {
 
@@ -355,8 +363,8 @@ void CouenneCutGenerator::generateCuts (const OsiSolverInterface &si,
 	u = con -> Ub () -> Value ();
 
       // tighten bounds in Couenne's problem representation
-      problem_ -> Lb (index) = CoinMax (l, problem_ -> Lb (index));
-      problem_ -> Ub (index) = CoinMin (u, problem_ -> Ub (index));
+      problem_ -> Lb (objindex) = CoinMax (l, problem_ -> Lb (objindex));
+      problem_ -> Ub (objindex) = CoinMin (u, problem_ -> Ub (objindex));
     }
   }
 
