@@ -6,7 +6,7 @@
 //                                                                           //
 // Author: Matthew Galati, Lehigh University                                 //
 //                                                                           //
-// Copyright (C) 2002-2011, Lehigh University, Matthew Galati, and Ted Ralphs//
+// Copyright (C) 2002-2013, Lehigh University, Matthew Galati, and Ted Ralphs//
 // All Rights Reserved.                                                      //
 //===========================================================================//
 
@@ -189,7 +189,18 @@ void MCF_DecompApp::createModelCore(DecompConstraintSet * model){
       }
       //TODO: any issue with range constraints?
       model->appendRow(row, -DecompInf, arcUB);
+      string rowNameUB = "capUB(" +
+	 UtilIntToStr(a)            + "_" + 
+	 UtilIntToStr(arcs[a].tail) + "," +
+	 UtilIntToStr(arcs[a].head) + ")";
+	 model->rowNames.push_back(rowNameUB);
+
       model->appendRow(row, arcLB,  DecompInf);
+      string rowNameLB = "capLB(" +
+	 UtilIntToStr(a)            + "_" + 
+	 UtilIntToStr(arcs[a].tail) + "," +
+	 UtilIntToStr(arcs[a].head) + ")";
+	 model->rowNames.push_back(rowNameLB);
    }
 
    //---
@@ -197,9 +208,10 @@ void MCF_DecompApp::createModelCore(DecompConstraintSet * model){
    //---
    for(k = 0; k < numCommodities; k++){
       for(a = 0; a < numArcs; a++){
-         string colName = "x(comm_" + UtilIntToStr(k) + ",(" +
+         string colName = "x(comm_" + UtilIntToStr(k) + "," +
+            UtilIntToStr(a)            + "_" +
             UtilIntToStr(arcs[a].tail) + "," +
-            UtilIntToStr(arcs[a].head) + "))";
+            UtilIntToStr(arcs[a].head) + ")";
          model->colNames.push_back(colName);
       }
    }
@@ -283,6 +295,13 @@ void MCF_DecompApp::createModelRelax(DecompConstraintSet * model,
                           commodities[commId].demand);
       else 
          model->appendRow(row, 0.0, 0.0);
+
+      string rowName = "flow(" +	 
+	 UtilIntToStr(commId) + "_" +
+	 UtilIntToStr(i)      + "_" +
+	 UtilIntToStr(source) + "," + 
+	 UtilIntToStr(sink)   + ")";
+      model->rowNames.push_back(rowName);      
    }
 
    //---
