@@ -5,7 +5,7 @@
  *
  * \remarks
  * Copyright (C) 2005-2011, Horand Gassmann, Jun Ma, Kipp Martin,
- * Dalhousie University, Northwestern University, and the University of Chicago.
+ * Northwestern University, and the University of Chicago.
  * All Rights Reserved.
  * This software is licensed under the Eclipse Public License.
  * Please see the accompanying LICENSE file in root directory for terms.
@@ -38,7 +38,12 @@ OSgLParserData::OSgLParserData() :
     source(""),
     description(""),
     fileCreator(""),
-    licence("")
+    licence(""),
+    fileNamePresent(false),
+    sourcePresent(false),
+    descriptionPresent(false),
+    fileCreatorPresent(false),
+    licencePresent(false)
 
 {
 
