@@ -1,17 +1,19 @@
-/* $Id: cppad.hpp 1643 2010-02-04 05:45:21Z bradbell $ */
+/* $Id: cppad.hpp 2625 2012-12-23 14:34:12Z bradbell $ */
 # ifndef CPPAD_CPPAD_INCLUDED
 # define CPPAD_CPPAD_INCLUDED
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-10 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-12 Bradley M. Bell
 
 CppAD is distributed under multiple licenses. This distribution is under
 the terms of the
-                    Common Public License Version 1.0.
+                    Eclipse Public License Version 1.0.
 
 A copy of this license is included in the COPYING file of this distribution.
 Please visit http://www.coin-or.org/CppAD/ for information on other licenses.
 -------------------------------------------------------------------------- */
 /*!
+\defgroup cppad_hpp cppad.hpp
+\{
 \file cppad.hpp
 \brief includes the entire CppAD package in the necessary order.
 
@@ -19,20 +21,21 @@ Please visit http://www.coin-or.org/CppAD/ for information on other licenses.
 \brief contains all the variables and functions defined by the CppAD package.
 */
 
-# include <cppad/declare.hpp>            // forward declarations need by user
-// ---------------------------------------------------------------------------
-# include <cppad/local/base_complex.hpp> // allow form complex Base types
+# include <cppad/base_require.hpp> // all base type requirements
 // ---------------------------------------------------------------------------
 // CppAD general purpose library routines (can be included separately)
 
 # include <cppad/check_numeric_type.hpp>
 # include <cppad/check_simple_vector.hpp>
+# include <cppad/index_sort.hpp>
 # include <cppad/local/cppad_assert.hpp>
 # include <cppad/lu_solve.hpp>
+# include <cppad/memory_leak.hpp>
 # include <cppad/near_equal.hpp>
 # include <cppad/ode_err_control.hpp>
 # include <cppad/ode_gear.hpp>
 # include <cppad/ode_gear_control.hpp>
+# include <cppad/omp_alloc.hpp>
 # include <cppad/poly.hpp>
 # include <cppad/pow_int.hpp>
 # include <cppad/romberg_mul.hpp>
@@ -40,7 +43,9 @@ Please visit http://www.coin-or.org/CppAD/ for information on other licenses.
 # include <cppad/rosen_34.hpp>
 # include <cppad/runge_45.hpp>
 # include <cppad/speed_test.hpp>
+# include <cppad/time_test.hpp>
 # include <cppad/track_new_del.hpp>
+# include <cppad/thread_alloc.hpp>
 # include <cppad/vector.hpp>
 
 // --------------------------------------------------------------------------
@@ -61,6 +66,9 @@ Please visit http://www.coin-or.org/CppAD/ for information on other licenses.
 # include <cppad/local/define.hpp>
 
 // vectors used with CppAD
+# include <cppad/local/testvector.hpp>
+
+// deprecated vectors used with CppAD
 # include <cppad/local/test_vector.hpp>
 
 // Declare classes and fucntions that are used before defined
@@ -88,4 +96,5 @@ Please visit http://www.coin-or.org/CppAD/ for information on other licenses.
 // undo definitions in Define.h
 # include <cppad/local/undef.hpp>   
 
+/*! \} */
 # endif
