@@ -1,10 +1,10 @@
-/* $Id: mul.cpp 1370 2009-05-31 05:31:50Z bradbell $ */
+/* $Id: mul.cpp 2506 2012-10-24 19:36:49Z bradbell $ */
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-07 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-12 Bradley M. Bell
 
 CppAD is distributed under multiple licenses. This distribution is under
 the terms of the 
-                    Common Public License Version 1.0.
+                    Eclipse Public License Version 1.0.
 
 A copy of this license is included in the COPYING file of this distribution.
 Please visit http://www.coin-or.org/CppAD/ for information on other licenses.
@@ -23,7 +23,7 @@ bool MulTestOne(void)
 	using namespace CppAD;
 
 	// independent variable vector, indices, values, and declaration
-	CPPAD_TEST_VECTOR< AD<double> > U(2);
+	CPPAD_TESTVECTOR(AD<double>) U(2);
 	size_t s = 0;
 	size_t t = 1;
 	U[s]     = 3.;
@@ -35,7 +35,7 @@ bool MulTestOne(void)
 	AD<double> one  = 1.;
 
 	// dependent variable vector and indices
-	CPPAD_TEST_VECTOR< AD<double> > Z(5);
+	CPPAD_TESTVECTOR(AD<double>) Z(5);
 	size_t x = 0;
 	size_t y = 1;
 	size_t z = 2;
@@ -54,8 +54,8 @@ bool MulTestOne(void)
 
 	// create f: U -> Z and vectors used for derivative calculations
 	ADFun<double> f(U, Z);
-	CPPAD_TEST_VECTOR<double> q( f.Domain() );
-	CPPAD_TEST_VECTOR<double> r( f.Range() );
+	CPPAD_TESTVECTOR(double) q( f.Domain() );
+	CPPAD_TESTVECTOR(double) r( f.Range() );
 
 	// check parameter flag
 	ok &= f.Parameter(v);
@@ -78,7 +78,7 @@ bool MulTestOne(void)
 	ok &= ( r[v] == 0. );             // dv/ds
 
 	// reverse computation of second partials of z
-	CPPAD_TEST_VECTOR<double> d2( f.Domain() * 2 );
+	CPPAD_TESTVECTOR(double) d2( f.Domain() * 2 );
 	r[x] = 0.;
 	r[y] = 0.;
 	r[z] = 1.;
@@ -100,7 +100,7 @@ bool MulTestTwo(void)
 
 	// independent variable vector
 	double u0 = .5;
-	CPPAD_TEST_VECTOR< AD<double> > U(1);
+	CPPAD_TESTVECTOR(AD<double>) U(1);
 	U[0]      = u0;
 	Independent(U);
 
@@ -110,13 +110,13 @@ bool MulTestTwo(void)
 	AD<double> d = 4  * c;    // int        * AD<double> 
 
 	// dependent variable vector 
-	CPPAD_TEST_VECTOR< AD<double> > Z(1);
+	CPPAD_TESTVECTOR(AD<double>) Z(1);
 	Z[0] = U[0] * d;          // AD<double> * AD<double>
 
 	// create f: U -> Z and vectors used for derivative calculations
 	ADFun<double> f(U, Z); 
-	CPPAD_TEST_VECTOR<double> v(1);
-	CPPAD_TEST_VECTOR<double> w(1);
+	CPPAD_TESTVECTOR(double) v(1);
+	CPPAD_TESTVECTOR(double) w(1);
 
 	// check value 
 	ok &= NearEqual(Value(Z[0]) , u0*4*3*2*u0,  1e-10 , 1e-10);
@@ -141,7 +141,7 @@ bool MulTestTwo(void)
 	}
 
 	// reverse computation of partials of Taylor coefficients
-	CPPAD_TEST_VECTOR<double> r(p); 
+	CPPAD_TESTVECTOR(double) r(p); 
 	w[0]  = 1.;
 	r     = f.Reverse(p, w);
 	jfac  = 1.;
