@@ -1,10 +1,10 @@
-/* $Id: mul_level.cpp 1697 2010-04-29 03:23:30Z bradbell $ */
+/* $Id: mul_level.cpp 2506 2012-10-24 19:36:49Z bradbell $ */
 /* --------------------------------------------------------------------------
-CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-10 Bradley M. Bell
+CppAD: C++ Algorithmic Differentiation: Copyright (C) 2003-12 Bradley M. Bell
 
 CppAD is distributed under multiple licenses. This distribution is under
 the terms of the 
-                    Common Public License Version 1.0.
+                    Eclipse Public License Version 1.0.
 
 A copy of this license is included in the COPYING file of this distribution.
 Please visit http://www.coin-or.org/CppAD/ for information on other licenses.
@@ -17,7 +17,7 @@ Please visit http://www.coin-or.org/CppAD/ for information on other licenses.
 # include <adolc/interfaces.h>
 // adouble definitions not in Adolc distribution and 
 // required in order to use CppAD::AD<adouble>
-# include "../example/base_adolc.hpp"
+# include <cppad/example/base_adolc.hpp>
 # endif
 
 # include <cppad/cppad.hpp>
@@ -35,8 +35,8 @@ bool One(void)
 	typedef CppAD::AD<ADdouble> ADDdouble;   // for two levels of taping
 	size_t n = 2;                            // dimension for example
 
-	CPPAD_TEST_VECTOR<ADdouble>   a_x(n);
-	CPPAD_TEST_VECTOR<ADDdouble> aa_x(n);
+	CPPAD_TESTVECTOR(ADdouble)   a_x(n);
+	CPPAD_TESTVECTOR(ADDdouble) aa_x(n);
 
 	// value of the independent variables
 	a_x[0] = 2.; a_x[1] = 3.;
@@ -45,26 +45,26 @@ bool One(void)
 	CppAD::Independent(aa_x);
 
 	// compute the function f(x) = 2 * x[0] * x[1]
-	CPPAD_TEST_VECTOR<ADDdouble> aa_f(1);
+	CPPAD_TESTVECTOR(ADDdouble) aa_f(1);
 	aa_f[0] = 2. * aa_x[0] * aa_x[1];
 	CppAD::ADFun<ADdouble> F(aa_x, aa_f);
 
 	// re-evaluate f(2, 3) (must get proper deepedence on a_x).
 	size_t p = 0;
-	CPPAD_TEST_VECTOR<ADdouble> a_fp(1);
+	CPPAD_TESTVECTOR(ADdouble) a_fp(1);
 	a_fp    = F.Forward(p, a_x);
 	ok     &= NearEqual(a_fp[0], 2. * a_x[0] * a_x[1], eps, eps);
 
 	// compute the function g(x) = 2 * partial_x[0] f(x) = 4 * x[1]
 	p = 1;
-	CPPAD_TEST_VECTOR<ADdouble> a_dx(n), a_g(1);
+	CPPAD_TESTVECTOR(ADdouble) a_dx(n), a_g(1);
 	a_dx[0] = 1.; a_dx[1] = 0.;
 	a_fp    = F.Forward(p, a_dx);
 	a_g[0]  = 2. * a_fp[0];
 	CppAD::ADFun<double> G(a_x, a_g);
 
 	// compute partial_x[1] g(x)
-	CPPAD_TEST_VECTOR<double>  xp(n), gp(1);
+	CPPAD_TESTVECTOR(double)  xp(n), gp(1);
 	p = 0;
 	xp[0] = 4.; xp[1] = 5.;
 	gp    = G.Forward(p, xp);
@@ -80,7 +80,7 @@ bool One(void)
 
 // f(x) = |x|^2 = .5 * ( x[0]^2 + ... + x[n-1]^2 )
 template <class Type>
-Type f_Two(CPPAD_TEST_VECTOR<Type> &x)
+Type f_Two(CPPAD_TESTVECTOR(Type) &x)
 {	Type sum;
 
 	// check assignment of AD< AD<double> > = double
@@ -106,9 +106,9 @@ bool Two(void)
 	size_t n = 5;                            // dimension for example
 	size_t j;                                // a temporary index variable
 
-	CPPAD_TEST_VECTOR<double>       x(n);
-	CPPAD_TEST_VECTOR<ADdouble>   a_x(n);
-	CPPAD_TEST_VECTOR<ADDdouble> aa_x(n);
+	CPPAD_TESTVECTOR(double)       x(n);
+	CPPAD_TESTVECTOR(ADdouble)   a_x(n);
+	CPPAD_TESTVECTOR(ADDdouble) aa_x(n);
 
 	// value of the independent variables
 	for(j = 0; j < n; j++)
@@ -119,7 +119,7 @@ bool Two(void)
 	CppAD::Independent(aa_x);          // aa_x is independent for ADDdouble
 
 	// compute function
-	CPPAD_TEST_VECTOR<ADDdouble> aa_f(1);    // scalar valued function
+	CPPAD_TESTVECTOR(ADDdouble) aa_f(1);    // scalar valued function
 	aa_f[0] = f_Two(aa_x);                   // has only one component
 
 	// declare inner function (corresponding to ADDdouble calculation)
@@ -127,8 +127,8 @@ bool Two(void)
 
 	// compute f'(x) 
 	size_t p = 1;                        // order of derivative of a_F
-	CPPAD_TEST_VECTOR<ADdouble> a_w(1);  // weight vector for a_F
-	CPPAD_TEST_VECTOR<ADdouble> a_df(n); // value of derivative
+	CPPAD_TESTVECTOR(ADdouble) a_w(1);  // weight vector for a_F
+	CPPAD_TESTVECTOR(ADdouble) a_df(n); // value of derivative
 	a_w[0] = 1;                          // weighted function same as a_F
 	a_df   = a_F.Reverse(p, a_w);        // gradient of f
 
@@ -136,8 +136,8 @@ bool Two(void)
 	CppAD::ADFun<double> df(a_x, a_df);
 
 	// compute the d/dx of f'(x) * v = f''(x) * v
-	CPPAD_TEST_VECTOR<double> v(n);
-	CPPAD_TEST_VECTOR<double> ddf_v(n);
+	CPPAD_TESTVECTOR(double) v(n);
+	CPPAD_TESTVECTOR(double) ddf_v(n);
 	for(j = 0; j < n; j++)
 		v[j] = double(n - j);
 	ddf_v = df.Reverse(p, v);
@@ -153,16 +153,16 @@ bool Two(void)
 
 # ifdef CPPAD_ADOLC_TEST
 
-bool Three(void) 
+bool adolc(void) 
 {	bool ok = true;                   // initialize test result
 
 	typedef adouble      ADdouble;         // for first level of taping
 	typedef CppAD::AD<ADdouble> ADDdouble; // for second level of taping
 	size_t n = 5;                          // number independent variables
 
-	CPPAD_TEST_VECTOR<double>       x(n);
-	CPPAD_TEST_VECTOR<ADdouble>   a_x(n);
-	CPPAD_TEST_VECTOR<ADDdouble> aa_x(n);
+	CPPAD_TESTVECTOR(double)       x(n);
+	CPPAD_TESTVECTOR(ADdouble)   a_x(n);
+	CPPAD_TESTVECTOR(ADDdouble) aa_x(n);
 
 	// value of the independent variables
 	int tag = 0;                         // Adolc setup
@@ -178,7 +178,7 @@ bool Three(void)
 	CppAD::Independent(aa_x);          // aa_x is independent for ADDdouble
 
 	// compute function
-	CPPAD_TEST_VECTOR<ADDdouble> aa_f(1);    // scalar valued function
+	CPPAD_TESTVECTOR(ADDdouble) aa_f(1);    // scalar valued function
 	aa_f[0] = f_Two(aa_x);                   // has only one component
 
 	// declare inner function (corresponding to ADDdouble calculation)
@@ -186,8 +186,8 @@ bool Three(void)
 
 	// compute f'(x) 
 	size_t p = 1;                        // order of derivative of a_F
-	CPPAD_TEST_VECTOR<ADdouble> a_w(1);  // weight vector for a_F
-	CPPAD_TEST_VECTOR<ADdouble> a_df(n); // value of derivative
+	CPPAD_TESTVECTOR(ADdouble) a_w(1);  // weight vector for a_F
+	CPPAD_TESTVECTOR(ADdouble) a_df(n); // value of derivative
 	a_w[0] = 1;                          // weighted function same as a_F
 	a_df   = a_F.Reverse(p, a_w);        // gradient of f
 
@@ -220,6 +220,98 @@ bool Three(void)
 
 # endif // CPPAD_ADOLC_TEST
 
+bool std_math(void)
+{	bool ok = true;
+	using CppAD::AD;
+	using CppAD::Independent;
+	using CppAD::ADFun;
+	double eps = std::numeric_limits<double>::epsilon();
+
+
+	typedef AD<double>      ADdouble; // for first level of taping
+	typedef AD<ADdouble>   ADDdouble; // for second level of taping
+	size_t n = 1;         // number independent variables
+	size_t m = 1;         // number dependent and independent variables
+
+	CPPAD_TESTVECTOR(double)       x(n),   y(m);
+	CPPAD_TESTVECTOR(ADdouble)    ax(n),  ay(m);
+	CPPAD_TESTVECTOR(ADDdouble)  aax(n), aay(m);
+
+	// create af(x) = tanh(x)
+	aax[0] = 1.;
+	Independent( aax );
+	aay[0] = tanh(aax[0]);
+	ADFun<ADdouble> af(aax, aay);
+
+	// create g(x) = af(x)
+	ax[0] = 1.;
+	Independent( ax );
+	ay = af.Forward(0, ax);
+	ADFun<double> g(ax, ay);
+
+	// evaluate h(x) = g(x) 
+	x[0] = 1.;
+	y = g.Forward(0, x);
+
+	// check result
+	double check  = tanh(x[0]);
+	ok &= CppAD::NearEqual(y[0], check, eps, eps);
+
+	return ok;
+}
+
+// supress this test until ../bug/abs.sh is fixed
+# ifdef CPPAD_NOT_DEFINED
+bool abs(void)
+{	bool ok = true;
+	using CppAD::AD;
+	using CppAD::Independent;
+	using CppAD::ADFun;
+	double eps = std::numeric_limits<double>::epsilon();
+
+
+	typedef AD<double>      ADdouble; // for first level of taping
+	typedef AD<ADdouble>   ADDdouble; // for second level of taping
+	size_t n = 1;         // number independent variables
+	size_t m = 1;         // number dependent and independent variables
+
+	CPPAD_TESTVECTOR(double)       x(n),   y(m);
+	CPPAD_TESTVECTOR(ADdouble)    ax(n),  ay(m);
+	CPPAD_TESTVECTOR(ADDdouble)  aax(n), aay(m);
+
+	// create af(x) = abs(x)
+	aax[0] = 1.;
+	Independent( aax );
+	aay[0] = abs(aax[0]);
+	ADFun<ADdouble> af(aax, aay);
+
+	// create g(x) = af'(x)
+	ax[0] = 1.;
+	Independent( ax );
+	ay = af.Jacobian(ax);
+	ADFun<double> g(ax, ay);
+
+	// evaluate g(x) at same x as recording
+	x[0] = 1.;
+	y = g.Forward(0, x);
+
+	// check result
+	double check  = 1.;
+	ok &= CppAD::NearEqual(y[0], check, eps, eps);
+
+	// evaluate g(x) at different x from recording
+	// (but abs is an atomic operation so derivative should work)
+	x[0] = -1.;
+	y = g.Forward(0, x);
+
+	// check result
+	check  = -1.;
+	ok &= CppAD::NearEqual(y[0], check, eps, eps);
+
+	return ok;
+}
+# endif
+
 } // END empty namespace
 
 bool mul_level(void)
@@ -227,7 +319,12 @@ bool mul_level(void)
 	ok     &= One();
 	ok     &= Two();
 # ifdef CPPAD_ADOLC_TEST
-	ok     &= Three();
+	ok     &= adolc();
 # endif
+	ok     &= std_math();
+# ifdef CPPAD_NOT_DEFINED
+	ok     &= abs();
+# endif
+
 	return ok;
 }
